@@ -1,5 +1,5 @@
 ;; -*- no-byte-compile: t; lexical-binding: nil -*-
-(define-package "binder" "0.5.0"
+(define-package "binder" "20250101.1950"
   "Global minor mode to facilitate multi-file writing projects."
   '((emacs "24.4")
     (seq   "2.20"))
